@@ -446,7 +446,8 @@ class QuenchPlanAnalysis():
         for group in tdms_file.groups():
             if group.name == 'HF': self.TDMSdata.groupHF = tdms_file['HF']
             elif group.name == 'MF': self.TDMSdata.groupMF = tdms_file['MF']
-            else: print("Don't understand group: ", group)
+            else:
+                if self.verbose: print("Don't understand group: ", group)
 
         ## Pick channels and store conveniently
         I_Heaters = []
@@ -458,12 +459,12 @@ class QuenchPlanAnalysis():
                 self.TDMSdata.I_DCCT_MF = channel.data*1000
                 self.TDMSdata.t_steps_MF = channel.properties['wf_samples']
                 self.TDMSdata.t_d_MF = channel.properties['wf_increment']
-            if channel.name == 'Trigger_PC':
+            if channel.name == 'Trigger_PC' or channel.name == 'Trigger_HF':
                 trigger_data = channel.data
-            if channel.name == 'I Cliq':self.TDMSdata.I_CLIQ = channel.data
-            if channel.name == 'V Cliq': self.TDMSdata.U_CLIQ = channel.data
-            if channel.name.startswith("I_Heater"): I_Heaters.append(channel.name)
-            if channel.name.startswith("U_Heater"): U_Heaters.append(channel.name)
+            if channel.name == 'I Cliq' or channel.name == 'I_CLIQ':self.TDMSdata.I_CLIQ = channel.data
+            if channel.name == 'V Cliq' or channel.name == 'U_CLIQ': self.TDMSdata.U_CLIQ = channel.data
+            if channel.name.startswith("I_Heater") or channel.name.startswith("I(Alim__QH_"): I_Heaters.append(channel.name)
+            if channel.name.startswith("U_Heater") or channel.name.startswith("U(Alim_QH_"): U_Heaters.append(channel.name)
         ## Set up Timeframe
         self.TDMSdata.TimeFrame_MF = np.linspace(0,self.TDMSdata.t_steps_MF*self.TDMSdata.t_d_MF, int(self.TDMSdata.t_steps_MF))
         #self.TDMSdata.goupHF['IDCCT_HF'].time_track()
@@ -489,8 +490,10 @@ class QuenchPlanAnalysis():
         Heat_len = len(self.TDMSdata.groupMF[Heaters[0]].data[trigger_shoot:])
         if Heaters[0].startswith('I'): self.TDMSdata.I_QH = np.zeros((len(Heaters), Heat_len))
         elif Heaters[0].startswith('U'): self.TDMSdata.U_QH = np.zeros((len(Heaters), Heat_len))
+        if Heaters[0].endswith(')'): idxOrder = -2
+        else: idxOrder = -1
         for k in Heaters:
-            order = int(k[-1])
+            order = int(k[idxOrder ])
             if Heaters[0].startswith('I'): self.TDMSdata.I_QH[order-1] = self.TDMSdata.groupMF[k].data[trigger_shoot:]
             elif Heaters[0].startswith('U'): self.TDMSdata.U_QH[order-1] = self.TDMSdata.groupMF[k].data[trigger_shoot:]
 
@@ -518,8 +521,8 @@ class QuenchPlanAnalysis():
                     chName = chName.replace(" ", "")
                     try:
                         res = temp_Sections_1.match(chName).groups()
-                        ChN = res + (str(res[0] + res[1] + '_'  + res[3] + "_" + res[5]),) + (
-                        str(res[0] + res[1] + '_' + res[5] + "_"  + res[3]),) + (channel.name,)
+                        ChN = res + (str(res[0] + res[1] + '_'  + res[3] + "-" + res[5]),) + (
+                        str(res[0] + res[1] + '_' + res[5] + "-"  + res[3]),) + (channel.name,)
                         CSections.append(ChN)
                     except:
                         pass
