@@ -162,7 +162,7 @@ def testvQ():
     [vQ, l, th_con_h, delta_t_h, th_con_w, delta_t_w] = a.adjust_vQ(RoxieFile)
     return a
 
-def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = False):
+def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = True):
     Coil108 = {'C108_I1_I2':[],
                'C108_I2_I3':np.concatenate((np.linspace(29, 45, 17), np.linspace(229, 245, 17))),
                'C108_I3_I4':np.concatenate((np.linspace(46, 49, 4), np.linspace(246, 249, 4))),
@@ -229,7 +229,7 @@ def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim, verbose = False):
     a.ProvideTurnsToCoilStructure(CoilCsv = 'C:\cernbox\MasterThesis\CoilStructure_MQXFPB2.csv')
     # a.QuenchPlanAnalysis(Plot = 1)
     # a.FindQuenchTDMS(0.1, 0.007, Plot=0)
-    a.PlotVoltageTap(Coil = 110)
+    a.PlotVoltageTap(Coil = 1)
     # a.PlotVoltageTap(TapName = 'C109_I2_I3')
     # a.calculateAllQuenchIntegrals(TDMS = 0)
     # a.calculateAllQuenchIntegrals(SIM = 0)
@@ -272,9 +272,11 @@ def PrepareSimulations():
 
 # a  = testvQ()
 
+td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFPB01\\HCLMQXFBT01-CR000001__A202007140955_a001(0).tdms"
+
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810151854_a026(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111418_a003(0).tdms"
-td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111846_a008(0).tdms"
+# td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810111846_a008(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810101854_tb017(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810101725_tb016(0).tdms"
 # td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\\MQXFS4b\\HCMQXSM001-CR000042__H1810171217_a041(0).tdms"
