@@ -3,6 +3,7 @@ import json
 import pandas as pd
 import numpy as np
 import shutil
+import datetime
 
 from steam_nb_api.resources.ResourceReader import ResourceReader
 from steam_nb_api.utils.misc import makeCopyFile
@@ -181,10 +182,13 @@ class ParametersCOSIM:
                 makeCopyFile(fileName_complementaryIOPortDefinition,
                              os.path.join(nameFolderCosimModel, 'LEDET'+str(i), 'LedetInputOutputPortDefinition.json'))
 
-    def makeGenericIOPortFiles(self, CoilSections, CurrentFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
+    def makeGenericIOPortFiles(self, CoilSections, ModelFolder, CoSimFolder: str, PSpiceExecutable: str, LEDETExecutable: str,
                                t_0 = [0, 2e-5], t_end = [2e-5, 0.5], t_step_max = [[1e-5, 1e-5], [1e-5, 1e-5]],
                                relTolerance = [1e-4, None], absTolerance = [1, None], executionOrder = [1, 2],
                                executeCleanRun = [True, True], N_LEDET = 1, QuenchMagnet = 0, SimulationNumber = [0], DistinctMagnets = 1, PSPICEinitialConditions = []):
+
+        if ModelFolder.endswith('//'): ModelFolder.replace('//','\\')
+        elif not ModelFolder.endswith('\\'): ModelFolder = ModelFolder + '\\'
         if len(SimulationNumber) < N_LEDET: self.SimulationNumber = SimulationNumber + (N_LEDET - len(SimulationNumber))*[0]
         else: self.SimulationNumber = SimulationNumber
         # Components which are used in the Ports
@@ -213,11 +217,11 @@ class ParametersCOSIM:
                                     [[["U", ["EM"]]], [["U", ["EM"]]]]]
 
         # Building STEAM.config
-        PSpiceFolder = CurrentFolder + "\\cosim_model_" + self.circuitName + "\\PSpice\\"
+        PSpiceFolder = ModelFolder +"PSPICE\\"
         if N_LEDET == 1:
-            LedetFolder = CurrentFolder + "\\cosim_model_" + self.circuitName + "\\LEDET\\"
+            LedetFolder = ModelFolder + "LEDET\\"
         else:
-            LedetFolder = CurrentFolder + "\\cosim_model_" + self.circuitName + "\\LEDET_" + str(1)+ "\\"
+            LedetFolder =  ModelFolder + "LEDET_" + str(1)+"\\"
 
         filename = self.nameFolderCosimModel + '//STEAMConfig.json'
         try:
@@ -243,7 +247,7 @@ class ParametersCOSIM:
         if N_LEDET >1:
             for i in range(2, N_LEDET+1):
                 data["coSimulationModelSolvers"].append("LEDET")
-                LedetFolder = CurrentFolder + "\\cosim_model_" + self.circuitName + "\\LEDET_" + str(i)+ "\\"
+                LedetFolder = ModelFolder +'LEDET_' + str(i)+"\\"
                 data["coSimulationModelDirs"].append(LedetFolder)
                 data["coSimulationModelConfigs"].append("LedetConfig.json")
                 data["coSimulationPortDefinitions"].append("LedetInputOutputPortDefinition.json")
@@ -252,7 +256,7 @@ class ParametersCOSIM:
             json.dump(data, f, indent=4)
 
         # Building PSpiceConfig
-        filename = self.nameFolderCosimModel + '/PSpice/PSpiceConfig.json'
+        filename = os.path.join(self.nameFolderCosimModel,'PSpice','PSpiceConfig.json')
         with open(filename, 'r') as f:
             data = json.load(f)
             data["solverPath"] = PSpiceExecutable
@@ -268,7 +272,7 @@ class ParametersCOSIM:
 
         # Building LEDETConfig
         if N_LEDET == 1:
-            filename = self.nameFolderCosimModel + '/LEDET/LedetConfig.json'
+            filename = os.path.join(self.nameFolderCosimModel,'LEDET','LedetConfig.json')
             with open(filename, 'r') as f:
                 data = json.load(f)
                 data["solverPath"] = LEDETExecutable
@@ -286,7 +290,7 @@ class ParametersCOSIM:
                 SimulationNumber = [0]*N_LEDET
                 print("Simulation Number 0 is used for all LEDET models")
             for i in range(1,N_LEDET+1):
-                filename = self.nameFolderCosimModel + '/LEDET_'+str(i)+'/LedetConfig.json'
+                filename = os.path.join(self.nameFolderCosimModel,'LEDET_'+str(i),'LedetConfig.json')
                 with open(filename, 'r') as f:
                     data = json.load(f)
                     if executionOrder.count(2) > 1:
@@ -306,7 +310,7 @@ class ParametersCOSIM:
 
         # LEDETInputPortDefinitions
         if N_LEDET == 1:
-            filename = self.nameFolderCosimModel + '/LEDET/LedetInputOutputPortDefinition.json'
+            filename = os.path.join(self.nameFolderCosimModel,'LEDET','LedetInputOutputPortDefinition.json')
             try:
                 os.remove(filename)
             except:
@@ -351,7 +355,7 @@ class ParametersCOSIM:
                     f.write('\n')
         else:
             for l in range(0,N_LEDET):
-                filename = self.nameFolderCosimModel + '/LEDET_'+str(l+1)+'/LedetInputOutputPortDefinition.json'
+                filename = os.path.join(self.nameFolderCosimModel,'LEDET_'+str(l+1),'LedetInputOutputPortDefinition.json')
                 try:
                     os.remove(filename)
                 except:
@@ -396,7 +400,7 @@ class ParametersCOSIM:
                         f.write('\n')
 
         # PSpice
-        filename = self.nameFolderCosimModel + '/PSpice/PSpiceInputOutputPortDefinition.json'
+        filename = os.path.join(self.nameFolderCosimModel,'PSpice','PSpiceInputOutputPortDefinition.json')
         try:
             os.remove(filename)
         except:
@@ -538,7 +542,7 @@ class ParametersCOSIM:
             for file in sourcefiles:
                 if file.endswith('.map2d') and not file.startswith(".sys"):
                     makeCopyFile(os.path.join(sourcedir, file), os.path.join(destinationpath_field, file))
-                if file.endswith(str(SimNumber) +'.xlsx') and not file.startswith(".sys") and file.startswith(str(nM)):
+                if file.endswith(str(nM)+"_"+str(SimNumber) +'.xlsx') and not file.startswith(".sys"):
                     shutil.copy(os.path.join(sourcedir, file), os.path.join(destinationpath_para, file))
                     LEDET_Fs.append(os.path.join(destinationpath_para, file))
                 if file.endswith('_selfMutualInductanceMatrix.csv'):
@@ -599,3 +603,17 @@ class ParametersCOSIM:
             steps = steps + abs(abs(tV[i])-abs(tV[i+2]))/tV[i+1]
 
         return [TurnNumber, steps]
+
+    def writeCOSIMBatch(self, COSIMfolder, COSIMexe, Destination = ''):
+        if type(COSIMfolder) != list:
+            COSIMfolder = [COSIMfolder]
+        if Destination: fileName = Destination+'COSIM_nb_Batch.bat'
+        else: fileName = 'COSIM_nb_Batch.bat'
+        fN = open(fileName, 'w+')
+
+        txt_stub = "java -jar " + COSIMexe
+        for i in range(len(COSIMfolder)):
+            tx_line = txt_stub + " " + str(COSIMfolder[i]) + "\\STEAMConfig.json" + " \n "
+            fN.write(tx_line)
+        fN.close()
+
